@@ -4,7 +4,9 @@ from .bankaccounts_client import BankaccountsDeleteModel
 from .bankaccounts_client import BankaccountsGetAllModel
 from .bankaccounts_client import BankaccountsInsertModel
 from .bankaccounts_client import BankaccountsUpdateModel
-from .billsoflading_client import Associated_documents
+from .billsoflading_client import (
+    Associated_documents as BillsofladingClientAssociated_documentsModel,
+)
 from .billsoflading_client import BillsofladingClient
 from .billsoflading_client import BillsofladingCountModel
 from .billsoflading_client import BillsofladingDeleteModel
@@ -13,18 +15,20 @@ from .billsoflading_client import BillsofladingGetOneModel
 from .billsoflading_client import BillsofladingInsertModel
 from .billsoflading_client import BillsofladingSetTransportCodeModel
 from .billsoflading_client import BillsofladingUpdateModel
-from .billsoflading_client import Payments
-from .billsoflading_client import Products
+from .billsoflading_client import Payments as BillsofladingClientPaymentsModel
+from .billsoflading_client import Products as BillsofladingClientProductsModel
 from .companies_client import CompaniesClient
 from .companies_client import CompaniesGetOneModel
 from .companies_client import CompaniesUpdateModel
-from .companies_client import Suppliers
-from .companies_client import Taxes
-from .companies_client import Warehouses
+from .companies_client import Suppliers as CompaniesClientSuppliersModel
+from .companies_client import Taxes as CompaniesClientTaxesModel
+from .companies_client import Warehouses as CompaniesClientWarehousesModel
 from .countries_client import CountriesClient
 from .countries_client import CountriesCountModifiedSinceModel
 from .countries_client import CountriesGetModifiedSinceModel
-from .creditnotes_client import Associated_documents
+from .creditnotes_client import (
+    Associated_documents as CreditnotesClientAssociated_documentsModel,
+)
 from .creditnotes_client import CreditnotesClient
 from .creditnotes_client import CreditnotesCountModel
 from .creditnotes_client import CreditnotesDeleteModel
@@ -32,8 +36,8 @@ from .creditnotes_client import CreditnotesGetAllModel
 from .creditnotes_client import CreditnotesGetOneModel
 from .creditnotes_client import CreditnotesInsertModel
 from .creditnotes_client import CreditnotesUpdateModel
-from .creditnotes_client import Payments
-from .creditnotes_client import Products
+from .creditnotes_client import Payments as CreditnotesClientPaymentsModel
+from .creditnotes_client import Products as CreditnotesClientProductsModel
 from .currencies_client import CurrenciesClient
 from .currencies_client import CurrenciesCountModifiedSinceModel
 from .currencies_client import CurrenciesGetModifiedSinceModel
@@ -48,7 +52,9 @@ from .customeralternateaddresses_client import (
 )
 from .customeralternateaddresses_client import CustomeralternateaddressesInsertModel
 from .customeralternateaddresses_client import CustomeralternateaddressesUpdateModel
-from .customerreturnnotes_client import Associated_documents
+from .customerreturnnotes_client import (
+    Associated_documents as CustomerreturnnotesClientAssociated_documentsModel,
+)
 from .customerreturnnotes_client import CustomerreturnnotesClient
 from .customerreturnnotes_client import CustomerreturnnotesCountModel
 from .customerreturnnotes_client import CustomerreturnnotesDeleteModel
@@ -57,8 +63,12 @@ from .customerreturnnotes_client import CustomerreturnnotesGetOneModel
 from .customerreturnnotes_client import CustomerreturnnotesInsertModel
 from .customerreturnnotes_client import CustomerreturnnotesSetTransportCodeModel
 from .customerreturnnotes_client import CustomerreturnnotesUpdateModel
-from .customerreturnnotes_client import Payments
-from .customerreturnnotes_client import Products
+from .customerreturnnotes_client import (
+    Payments as CustomerreturnnotesClientPaymentsModel,
+)
+from .customerreturnnotes_client import (
+    Products as CustomerreturnnotesClientProductsModel,
+)
 from .customers_client import CustomersClient
 from .customers_client import CustomersCountByNameModel
 from .customers_client import CustomersCountByNumberModel
@@ -77,7 +87,9 @@ from .customers_client import CustomersGetModifiedSinceModel
 from .customers_client import CustomersGetOneModel
 from .customers_client import CustomersInsertModel
 from .customers_client import CustomersUpdateModel
-from .debitnotes_client import Associated_documents
+from .debitnotes_client import (
+    Associated_documents as DebitnotesClientAssociated_documentsModel,
+)
 from .debitnotes_client import DebitnotesClient
 from .debitnotes_client import DebitnotesCountModel
 from .debitnotes_client import DebitnotesDeleteModel
@@ -85,8 +97,8 @@ from .debitnotes_client import DebitnotesGetAllModel
 from .debitnotes_client import DebitnotesGetOneModel
 from .debitnotes_client import DebitnotesInsertModel
 from .debitnotes_client import DebitnotesUpdateModel
-from .debitnotes_client import Payments
-from .debitnotes_client import Products
+from .debitnotes_client import Payments as DebitnotesClientPaymentsModel
+from .debitnotes_client import Products as DebitnotesClientProductsModel
 from .deductions_client import DeductionsClient
 from .deductions_client import DeductionsCountModifiedSinceModel
 from .deductions_client import DeductionsDeleteModel
@@ -101,7 +113,9 @@ from .deliverymethods_client import DeliverymethodsGetAllModel
 from .deliverymethods_client import DeliverymethodsGetModifiedSinceModel
 from .deliverymethods_client import DeliverymethodsInsertModel
 from .deliverymethods_client import DeliverymethodsUpdateModel
-from .deliverynotes_client import Associated_documents
+from .deliverynotes_client import (
+    Associated_documents as DeliverynotesClientAssociated_documentsModel,
+)
 from .deliverynotes_client import DeliverynotesClient
 from .deliverynotes_client import DeliverynotesCountModel
 from .deliverynotes_client import DeliverynotesDeleteModel
@@ -110,20 +124,22 @@ from .deliverynotes_client import DeliverynotesGetOneModel
 from .deliverynotes_client import DeliverynotesInsertModel
 from .deliverynotes_client import DeliverynotesSetTransportCodeModel
 from .deliverynotes_client import DeliverynotesUpdateModel
-from .deliverynotes_client import Payments
-from .deliverynotes_client import Products
+from .deliverynotes_client import Payments as DeliverynotesClientPaymentsModel
+from .deliverynotes_client import Products as DeliverynotesClientProductsModel
 from .documentmodels_client import DocumentmodelsClient
 from .documentmodels_client import DocumentmodelsCountModifiedSinceModel
 from .documentmodels_client import DocumentmodelsGetModifiedSinceModel
-from .documents_client import Associated_documents
+from .documents_client import (
+    Associated_documents as DocumentsClientAssociated_documentsModel,
+)
 from .documents_client import DocumentsClient
 from .documents_client import DocumentsCountModel
 from .documents_client import DocumentsGetAllDocumentTypesModel
 from .documents_client import DocumentsGetAllModel
 from .documents_client import DocumentsGetOneModel
 from .documents_client import DocumentsGetPdfLinkModel
-from .documents_client import Payments
-from .documents_client import Products
+from .documents_client import Payments as DocumentsClientPaymentsModel
+from .documents_client import Products as DocumentsClientProductsModel
 from .documentsets_client import DocumentsetsClient
 from .documentsets_client import DocumentsetsCountModifiedSinceModel
 from .documentsets_client import DocumentsetsDeleteModel
@@ -131,7 +147,9 @@ from .documentsets_client import DocumentsetsGetAllModel
 from .documentsets_client import DocumentsetsGetModifiedSinceModel
 from .documentsets_client import DocumentsetsInsertModel
 from .documentsets_client import DocumentsetsUpdateModel
-from .estimates_client import Associated_documents
+from .estimates_client import (
+    Associated_documents as EstimatesClientAssociated_documentsModel,
+)
 from .estimates_client import EstimatesClient
 from .estimates_client import EstimatesCountModel
 from .estimates_client import EstimatesDeleteModel
@@ -139,8 +157,8 @@ from .estimates_client import EstimatesGetAllModel
 from .estimates_client import EstimatesGetOneModel
 from .estimates_client import EstimatesInsertModel
 from .estimates_client import EstimatesUpdateModel
-from .estimates_client import Payments
-from .estimates_client import Products
+from .estimates_client import Payments as EstimatesClientPaymentsModel
+from .estimates_client import Products as EstimatesClientProductsModel
 from .fiscalzones_client import FiscalzonesClient
 from .fiscalzones_client import FiscalzonesCountModifiedSinceModel
 from .fiscalzones_client import FiscalzonesGetAllModel
@@ -154,7 +172,9 @@ from .identificationtemplates_client import IdentificationtemplatesGetAllModel
 from .identificationtemplates_client import IdentificationtemplatesGetModifiedSinceModel
 from .identificationtemplates_client import IdentificationtemplatesInsertModel
 from .identificationtemplates_client import IdentificationtemplatesUpdateModel
-from .invoicereceipts_client import Associated_documents
+from .invoicereceipts_client import (
+    Associated_documents as InvoicereceiptsClientAssociated_documentsModel,
+)
 from .invoicereceipts_client import InvoicereceiptsClient
 from .invoicereceipts_client import InvoicereceiptsCountModel
 from .invoicereceipts_client import InvoicereceiptsDeleteModel
@@ -162,9 +182,11 @@ from .invoicereceipts_client import InvoicereceiptsGetAllModel
 from .invoicereceipts_client import InvoicereceiptsGetOneModel
 from .invoicereceipts_client import InvoicereceiptsInsertModel
 from .invoicereceipts_client import InvoicereceiptsUpdateModel
-from .invoicereceipts_client import Payments
-from .invoicereceipts_client import Products
-from .invoices_client import Associated_documents
+from .invoicereceipts_client import Payments as InvoicereceiptsClientPaymentsModel
+from .invoicereceipts_client import Products as InvoicereceiptsClientProductsModel
+from .invoices_client import (
+    Associated_documents as InvoicesClientAssociated_documentsModel,
+)
 from .invoices_client import InvoicesClient
 from .invoices_client import InvoicesCountModel
 from .invoices_client import InvoicesDeleteModel
@@ -172,8 +194,8 @@ from .invoices_client import InvoicesGetAllModel
 from .invoices_client import InvoicesGetOneModel
 from .invoices_client import InvoicesInsertModel
 from .invoices_client import InvoicesUpdateModel
-from .invoices_client import Payments
-from .invoices_client import Products
+from .invoices_client import Payments as InvoicesClientPaymentsModel
+from .invoices_client import Products as InvoicesClientProductsModel
 from .languages_client import LanguagesClient
 from .languages_client import LanguagesCountModifiedSinceModel
 from .languages_client import LanguagesGetModifiedSinceModel
@@ -191,7 +213,9 @@ from .measurementunits_client import MeasurementunitsGetAllModel
 from .measurementunits_client import MeasurementunitsGetModifiedSinceModel
 from .measurementunits_client import MeasurementunitsInsertModel
 from .measurementunits_client import MeasurementunitsUpdateModel
-from .ownassetsmovementguides_client import Associated_documents
+from .ownassetsmovementguides_client import (
+    Associated_documents as OwnassetsmovementguidesClientAssociated_documentsModel,
+)
 from .ownassetsmovementguides_client import OwnassetsmovementguidesClient
 from .ownassetsmovementguides_client import OwnassetsmovementguidesCountModel
 from .ownassetsmovementguides_client import OwnassetsmovementguidesDeleteModel
@@ -200,8 +224,12 @@ from .ownassetsmovementguides_client import OwnassetsmovementguidesGetOneModel
 from .ownassetsmovementguides_client import OwnassetsmovementguidesInsertModel
 from .ownassetsmovementguides_client import OwnassetsmovementguidesSetTransportCodeModel
 from .ownassetsmovementguides_client import OwnassetsmovementguidesUpdateModel
-from .ownassetsmovementguides_client import Payments
-from .ownassetsmovementguides_client import Products
+from .ownassetsmovementguides_client import (
+    Payments as OwnassetsmovementguidesClientPaymentsModel,
+)
+from .ownassetsmovementguides_client import (
+    Products as OwnassetsmovementguidesClientProductsModel,
+)
 from .paymentmethods_client import PaymentmethodsClient
 from .paymentmethods_client import PaymentmethodsCountModifiedSinceModel
 from .paymentmethods_client import PaymentmethodsDeleteModel
@@ -215,9 +243,11 @@ from .productcategories_client import ProductcategoriesGetAllModel
 from .productcategories_client import ProductcategoriesGetModifiedSinceModel
 from .productcategories_client import ProductcategoriesInsertModel
 from .productcategories_client import ProductcategoriesUpdateModel
-from .productcategories_client import Suppliers
-from .productcategories_client import Taxes
-from .productcategories_client import Warehouses
+from .productcategories_client import Suppliers as ProductcategoriesClientSuppliersModel
+from .productcategories_client import Taxes as ProductcategoriesClientTaxesModel
+from .productcategories_client import (
+    Warehouses as ProductcategoriesClientWarehousesModel,
+)
 from .products_client import ProductsClient
 from .products_client import ProductsCountByEanModel
 from .products_client import ProductsCountByNameModel
@@ -235,12 +265,14 @@ from .products_client import ProductsGetModifiedSinceModel
 from .products_client import ProductsGetOneModel
 from .products_client import ProductsInsertModel
 from .products_client import ProductsUpdateModel
-from .products_client import Suppliers
-from .products_client import Taxes
-from .products_client import Warehouses
-from .receipts_client import Associated_documents
-from .receipts_client import Payments
-from .receipts_client import Products
+from .products_client import Suppliers as ProductsClientSuppliersModel
+from .products_client import Taxes as ProductsClientTaxesModel
+from .products_client import Warehouses as ProductsClientWarehousesModel
+from .receipts_client import (
+    Associated_documents as ReceiptsClientAssociated_documentsModel,
+)
+from .receipts_client import Payments as ReceiptsClientPaymentsModel
+from .receipts_client import Products as ReceiptsClientProductsModel
 from .receipts_client import ReceiptsClient
 from .receipts_client import ReceiptsCountModel
 from .receipts_client import ReceiptsDeleteModel
@@ -256,9 +288,11 @@ from .salesmen_client import SalesmenGetModifiedSinceModel
 from .salesmen_client import SalesmenGetOneModel
 from .salesmen_client import SalesmenInsertModel
 from .salesmen_client import SalesmenUpdateModel
-from .simplifiedinvoices_client import Associated_documents
-from .simplifiedinvoices_client import Payments
-from .simplifiedinvoices_client import Products
+from .simplifiedinvoices_client import (
+    Associated_documents as SimplifiedinvoicesClientAssociated_documentsModel,
+)
+from .simplifiedinvoices_client import Payments as SimplifiedinvoicesClientPaymentsModel
+from .simplifiedinvoices_client import Products as SimplifiedinvoicesClientProductsModel
 from .simplifiedinvoices_client import SimplifiedinvoicesClient
 from .simplifiedinvoices_client import SimplifiedinvoicesCountModel
 from .simplifiedinvoices_client import SimplifiedinvoicesDeleteModel
@@ -268,9 +302,9 @@ from .simplifiedinvoices_client import SimplifiedinvoicesInsertModel
 from .simplifiedinvoices_client import SimplifiedinvoicesUpdateModel
 from .subscription_client import SubscriptionClient
 from .subscription_client import SubscriptionGetOneModel
-from .subscription_client import Suppliers
-from .subscription_client import Taxes
-from .subscription_client import Warehouses
+from .subscription_client import Suppliers as SubscriptionClientSuppliersModel
+from .subscription_client import Taxes as SubscriptionClientTaxesModel
+from .subscription_client import Warehouses as SubscriptionClientWarehousesModel
 from .suppliers_client import SuppliersClient
 from .suppliers_client import SuppliersCountByNameModel
 from .suppliers_client import SuppliersCountByNumberModel
@@ -298,12 +332,11 @@ from .taxes_client import TaxesUpdateModel
 from .taxexemptions_client import TaxexemptionsClient
 from .taxexemptions_client import TaxexemptionsCountModifiedSinceModel
 from .taxexemptions_client import TaxexemptionsGetModifiedSinceModel
-from .users_client import Suppliers
-from .users_client import Taxes
+from .users_client import Suppliers as UsersClientSuppliersModel
+from .users_client import Taxes as UsersClientTaxesModel
 from .users_client import UsersClient
 from .users_client import UsersGetAllModel
-from .users_client import UsersUpdateMeModel
-from .users_client import Warehouses
+from .users_client import Warehouses as UsersClientWarehousesModel
 from .vehicles_client import VehiclesClient
 from .vehicles_client import VehiclesCountModifiedSinceModel
 from .vehicles_client import VehiclesDeleteModel
@@ -311,9 +344,9 @@ from .vehicles_client import VehiclesGetAllModel
 from .vehicles_client import VehiclesGetModifiedSinceModel
 from .vehicles_client import VehiclesInsertModel
 from .vehicles_client import VehiclesUpdateModel
-from .warehouses_client import Suppliers
-from .warehouses_client import Taxes
-from .warehouses_client import Warehouses
+from .warehouses_client import Suppliers as WarehousesClientSuppliersModel
+from .warehouses_client import Taxes as WarehousesClientTaxesModel
+from .warehouses_client import Warehouses as WarehousesClientWarehousesModel
 from .warehouses_client import WarehousesClient
 from .warehouses_client import WarehousesCountModifiedSinceModel
 from .warehouses_client import WarehousesDeleteModel
@@ -321,9 +354,11 @@ from .warehouses_client import WarehousesGetAllModel
 from .warehouses_client import WarehousesGetModifiedSinceModel
 from .warehouses_client import WarehousesInsertModel
 from .warehouses_client import WarehousesUpdateModel
-from .waybills_client import Associated_documents
-from .waybills_client import Payments
-from .waybills_client import Products
+from .waybills_client import (
+    Associated_documents as WaybillsClientAssociated_documentsModel,
+)
+from .waybills_client import Payments as WaybillsClientPaymentsModel
+from .waybills_client import Products as WaybillsClientProductsModel
 from .waybills_client import WaybillsClient
 from .waybills_client import WaybillsCountModel
 from .waybills_client import WaybillsDeleteModel
@@ -334,7 +369,6 @@ from .waybills_client import WaybillsSetTransportCodeModel
 from .waybills_client import WaybillsUpdateModel
 
 __all__ = [
-    "Associated_documents",
     "BankaccountsClient",
     "BankaccountsCountModifiedSinceModel",
     "BankaccountsDeleteModel",
@@ -342,6 +376,9 @@ __all__ = [
     "BankaccountsInsertModel",
     "BankaccountsUpdateModel",
     "BillsofladingClient",
+    "BillsofladingClientAssociated_documentsModel",
+    "BillsofladingClientPaymentsModel",
+    "BillsofladingClientProductsModel",
     "BillsofladingCountModel",
     "BillsofladingDeleteModel",
     "BillsofladingGetAllModel",
@@ -350,12 +387,18 @@ __all__ = [
     "BillsofladingSetTransportCodeModel",
     "BillsofladingUpdateModel",
     "CompaniesClient",
+    "CompaniesClientSuppliersModel",
+    "CompaniesClientTaxesModel",
+    "CompaniesClientWarehousesModel",
     "CompaniesGetOneModel",
     "CompaniesUpdateModel",
     "CountriesClient",
     "CountriesCountModifiedSinceModel",
     "CountriesGetModifiedSinceModel",
     "CreditnotesClient",
+    "CreditnotesClientAssociated_documentsModel",
+    "CreditnotesClientPaymentsModel",
+    "CreditnotesClientProductsModel",
     "CreditnotesCountModel",
     "CreditnotesDeleteModel",
     "CreditnotesGetAllModel",
@@ -373,6 +416,9 @@ __all__ = [
     "CustomeralternateaddressesInsertModel",
     "CustomeralternateaddressesUpdateModel",
     "CustomerreturnnotesClient",
+    "CustomerreturnnotesClientAssociated_documentsModel",
+    "CustomerreturnnotesClientPaymentsModel",
+    "CustomerreturnnotesClientProductsModel",
     "CustomerreturnnotesCountModel",
     "CustomerreturnnotesDeleteModel",
     "CustomerreturnnotesGetAllModel",
@@ -399,6 +445,9 @@ __all__ = [
     "CustomersInsertModel",
     "CustomersUpdateModel",
     "DebitnotesClient",
+    "DebitnotesClientAssociated_documentsModel",
+    "DebitnotesClientPaymentsModel",
+    "DebitnotesClientProductsModel",
     "DebitnotesCountModel",
     "DebitnotesDeleteModel",
     "DebitnotesGetAllModel",
@@ -420,6 +469,9 @@ __all__ = [
     "DeliverymethodsInsertModel",
     "DeliverymethodsUpdateModel",
     "DeliverynotesClient",
+    "DeliverynotesClientAssociated_documentsModel",
+    "DeliverynotesClientPaymentsModel",
+    "DeliverynotesClientProductsModel",
     "DeliverynotesCountModel",
     "DeliverynotesDeleteModel",
     "DeliverynotesGetAllModel",
@@ -431,6 +483,9 @@ __all__ = [
     "DocumentmodelsCountModifiedSinceModel",
     "DocumentmodelsGetModifiedSinceModel",
     "DocumentsClient",
+    "DocumentsClientAssociated_documentsModel",
+    "DocumentsClientPaymentsModel",
+    "DocumentsClientProductsModel",
     "DocumentsCountModel",
     "DocumentsGetAllDocumentTypesModel",
     "DocumentsGetAllModel",
@@ -444,6 +499,9 @@ __all__ = [
     "DocumentsetsInsertModel",
     "DocumentsetsUpdateModel",
     "EstimatesClient",
+    "EstimatesClientAssociated_documentsModel",
+    "EstimatesClientPaymentsModel",
+    "EstimatesClientProductsModel",
     "EstimatesCountModel",
     "EstimatesDeleteModel",
     "EstimatesGetAllModel",
@@ -462,6 +520,9 @@ __all__ = [
     "IdentificationtemplatesInsertModel",
     "IdentificationtemplatesUpdateModel",
     "InvoicereceiptsClient",
+    "InvoicereceiptsClientAssociated_documentsModel",
+    "InvoicereceiptsClientPaymentsModel",
+    "InvoicereceiptsClientProductsModel",
     "InvoicereceiptsCountModel",
     "InvoicereceiptsDeleteModel",
     "InvoicereceiptsGetAllModel",
@@ -469,6 +530,9 @@ __all__ = [
     "InvoicereceiptsInsertModel",
     "InvoicereceiptsUpdateModel",
     "InvoicesClient",
+    "InvoicesClientAssociated_documentsModel",
+    "InvoicesClientPaymentsModel",
+    "InvoicesClientProductsModel",
     "InvoicesCountModel",
     "InvoicesDeleteModel",
     "InvoicesGetAllModel",
@@ -493,6 +557,9 @@ __all__ = [
     "MeasurementunitsInsertModel",
     "MeasurementunitsUpdateModel",
     "OwnassetsmovementguidesClient",
+    "OwnassetsmovementguidesClientAssociated_documentsModel",
+    "OwnassetsmovementguidesClientPaymentsModel",
+    "OwnassetsmovementguidesClientProductsModel",
     "OwnassetsmovementguidesCountModel",
     "OwnassetsmovementguidesDeleteModel",
     "OwnassetsmovementguidesGetAllModel",
@@ -507,15 +574,19 @@ __all__ = [
     "PaymentmethodsGetModifiedSinceModel",
     "PaymentmethodsInsertModel",
     "PaymentmethodsUpdateModel",
-    "Payments",
     "ProductcategoriesClient",
+    "ProductcategoriesClientSuppliersModel",
+    "ProductcategoriesClientTaxesModel",
+    "ProductcategoriesClientWarehousesModel",
     "ProductcategoriesDeleteModel",
     "ProductcategoriesGetAllModel",
     "ProductcategoriesGetModifiedSinceModel",
     "ProductcategoriesInsertModel",
     "ProductcategoriesUpdateModel",
-    "Products",
     "ProductsClient",
+    "ProductsClientSuppliersModel",
+    "ProductsClientTaxesModel",
+    "ProductsClientWarehousesModel",
     "ProductsCountByEanModel",
     "ProductsCountByNameModel",
     "ProductsCountByReferenceModel",
@@ -533,6 +604,9 @@ __all__ = [
     "ProductsInsertModel",
     "ProductsUpdateModel",
     "ReceiptsClient",
+    "ReceiptsClientAssociated_documentsModel",
+    "ReceiptsClientPaymentsModel",
+    "ReceiptsClientProductsModel",
     "ReceiptsCountModel",
     "ReceiptsDeleteModel",
     "ReceiptsGetAllModel",
@@ -548,6 +622,9 @@ __all__ = [
     "SalesmenInsertModel",
     "SalesmenUpdateModel",
     "SimplifiedinvoicesClient",
+    "SimplifiedinvoicesClientAssociated_documentsModel",
+    "SimplifiedinvoicesClientPaymentsModel",
+    "SimplifiedinvoicesClientProductsModel",
     "SimplifiedinvoicesCountModel",
     "SimplifiedinvoicesDeleteModel",
     "SimplifiedinvoicesGetAllModel",
@@ -555,8 +632,10 @@ __all__ = [
     "SimplifiedinvoicesInsertModel",
     "SimplifiedinvoicesUpdateModel",
     "SubscriptionClient",
+    "SubscriptionClientSuppliersModel",
+    "SubscriptionClientTaxesModel",
+    "SubscriptionClientWarehousesModel",
     "SubscriptionGetOneModel",
-    "Suppliers",
     "SuppliersClient",
     "SuppliersCountByNameModel",
     "SuppliersCountByNumberModel",
@@ -574,7 +653,6 @@ __all__ = [
     "SuppliersGetOneModel",
     "SuppliersInsertModel",
     "SuppliersUpdateModel",
-    "Taxes",
     "TaxesClient",
     "TaxesCountModifiedSinceModel",
     "TaxesDeleteModel",
@@ -586,8 +664,10 @@ __all__ = [
     "TaxexemptionsCountModifiedSinceModel",
     "TaxexemptionsGetModifiedSinceModel",
     "UsersClient",
+    "UsersClientSuppliersModel",
+    "UsersClientTaxesModel",
+    "UsersClientWarehousesModel",
     "UsersGetAllModel",
-    "UsersUpdateMeModel",
     "VehiclesClient",
     "VehiclesCountModifiedSinceModel",
     "VehiclesDeleteModel",
@@ -595,8 +675,10 @@ __all__ = [
     "VehiclesGetModifiedSinceModel",
     "VehiclesInsertModel",
     "VehiclesUpdateModel",
-    "Warehouses",
     "WarehousesClient",
+    "WarehousesClientSuppliersModel",
+    "WarehousesClientTaxesModel",
+    "WarehousesClientWarehousesModel",
     "WarehousesCountModifiedSinceModel",
     "WarehousesDeleteModel",
     "WarehousesGetAllModel",
@@ -604,6 +686,9 @@ __all__ = [
     "WarehousesInsertModel",
     "WarehousesUpdateModel",
     "WaybillsClient",
+    "WaybillsClientAssociated_documentsModel",
+    "WaybillsClientPaymentsModel",
+    "WaybillsClientProductsModel",
     "WaybillsCountModel",
     "WaybillsDeleteModel",
     "WaybillsGetAllModel",
