@@ -1,8 +1,23 @@
 from pydantic import BaseModel, ValidationError
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Any
 
 from moloni.base.client import MoloniBaseClient
 from moloni.base.helpers import endpoint, fill_query_params, validate_data
+from moloni.base import ApiResponse
+
+
+class ApiRequestModel(BaseModel):
+    _api_client: Any = None
+
+    def connect(self, *args, **kwargs):
+        self._api_client = BillsofladingClient(*args, **kwargs)
+        return self
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        pass
 
 
 class Associated_documents(BaseModel):
@@ -30,7 +45,7 @@ class Products(BaseModel):
     warehouse_id: Optional[Any] = None
 
 
-class BillsofladingCountModel(BaseModel):
+class BillsofladingCountModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -39,13 +54,77 @@ class BillsofladingCountModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingDeleteModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.count(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingDeleteModel(ApiRequestModel):
     company_id: Union[str, int]
     document_id: Optional[Union[str, int]] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingGetAllModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.delete(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingGetAllModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -56,8 +135,40 @@ class BillsofladingGetAllModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingGetOneModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.get_all(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingGetOneModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -67,8 +178,40 @@ class BillsofladingGetOneModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingInsertModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.get_one(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingInsertModel(ApiRequestModel):
     company_id: Union[str, int]
     associated_documents: Optional[List[Associated_documents]] = None
     customer_id: Optional[Union[str, int]] = None
@@ -91,14 +234,78 @@ class BillsofladingInsertModel(BaseModel):
     vehicle_id: Optional[Union[str, int]] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingSetTransportCodeModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.insert(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingSetTransportCodeModel(ApiRequestModel):
     company_id: Union[str, int]
     document_id: Optional[Union[str, int]] = None
     transport_code: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class BillsofladingUpdateModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.set_transport_code(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class BillsofladingUpdateModel(ApiRequestModel):
     company_id: Union[str, int]
     associated_documents: Optional[List[Associated_documents]] = None
     customer_id: Optional[Union[str, int]] = None
@@ -122,6 +329,38 @@ class BillsofladingUpdateModel(BaseModel):
     vehicle_id: Optional[Union[str, int]] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
+
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.update(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
 
 class BillsofladingClient(MoloniBaseClient):
 
