@@ -1,36 +1,51 @@
 from pydantic import BaseModel, ValidationError
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Any
 
 from moloni.base.client import MoloniBaseClient
 from moloni.base.helpers import endpoint, fill_query_params, validate_data
+from moloni.base import ApiResponse
+
+
+class ApiRequestModel(BaseModel):
+    _api_client: Any = None
+
+    def connect(self, *args, **kwargs):
+        self._api_client = InvoicesClient(*args, **kwargs)
+        return self
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        pass
 
 
 class Associated_documents(BaseModel):
-    associated_id: Optional[Union[str, int]] = None
-    value: Optional[Union[str, int]] = None
+    associated_id: Optional[Any] = None
+    value: Optional[Any] = None
 
 
 class Payments(BaseModel):
-    date: Optional[Union[str, int]] = None
-    notes: Optional[Union[str, int]] = None
-    payment_method_id: Optional[Union[str, int]] = None
-    value: Optional[Union[str, int]] = None
+    date: Optional[Any] = None
+    notes: Optional[Any] = None
+    payment_method_id: Optional[Any] = None
+    value: Optional[Any] = None
 
 
 class Products(BaseModel):
-    discount: Optional[Union[str, int]] = None
-    exemption_reason: Optional[Union[str, int]] = None
-    name: Optional[Union[str, int]] = None
-    order: Optional[Union[str, int]] = None
-    price: Optional[Union[str, int]] = None
-    product_id: Optional[Union[str, int]] = None
-    qty: Optional[Union[str, int]] = None
-    summary: Optional[Union[str, int]] = None
-    taxes: Optional[Union[str, int]] = None
-    warehouse_id: Optional[Union[str, int]] = None
+    discount: Optional[Any] = None
+    exemption_reason: Optional[Any] = None
+    name: Optional[Any] = None
+    order: Optional[Any] = None
+    price: Optional[Any] = None
+    product_id: Optional[Any] = None
+    qty: Optional[Any] = None
+    summary: Optional[Any] = None
+    taxes: Optional[Any] = None
+    warehouse_id: Optional[Any] = None
 
 
-class InvoicesCountModel(BaseModel):
+class InvoicesCountModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -43,13 +58,77 @@ class InvoicesCountModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class InvoicesDeleteModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.count(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class InvoicesDeleteModel(ApiRequestModel):
     company_id: Union[str, int]
     document_id: Optional[Union[str, int]] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class InvoicesGetAllModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.delete(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class InvoicesGetAllModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -64,8 +143,40 @@ class InvoicesGetAllModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class InvoicesGetOneModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.get_all(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class InvoicesGetOneModel(ApiRequestModel):
     company_id: Union[str, int]
     customer_id: Optional[Union[str, int]] = None
     date: Optional[str] = None
@@ -79,8 +190,40 @@ class InvoicesGetOneModel(BaseModel):
     year: Optional[str] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class InvoicesInsertModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.get_one(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class InvoicesInsertModel(ApiRequestModel):
     company_id: Union[str, int]
     alternate_address_id: Optional[Union[str, int]] = None
     associated_documents: Optional[List[Associated_documents]] = None
@@ -111,8 +254,40 @@ class InvoicesInsertModel(BaseModel):
     vehicle_id: Optional[Union[str, int]] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
 
-class InvoicesUpdateModel(BaseModel):
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.insert(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
+
+class InvoicesUpdateModel(ApiRequestModel):
     company_id: Union[str, int]
     alternate_address_id: Optional[Union[str, int]] = None
     associated_documents: Optional[List[Associated_documents]] = None
@@ -144,6 +319,38 @@ class InvoicesUpdateModel(BaseModel):
     vehicle_id: Optional[Union[str, int]] = None
     your_reference: Optional[str] = None
 
+    def request(self) -> ApiResponse:
+        """
+        request(self) -> ApiResponse
+
+        Make an API request using the initialized client.
+
+        This method checks if the `_api_client` attribute is set (i.e., if the client has been initialized via the `connect` method).
+        If the client is initialized, it will make an API request using the provided method name and the model's data,
+        excluding the `_api_client` attribute itself from the request payload. If the client is not initialized, it will raise a `ValueError`.
+
+        Returns:
+            The response from the API.
+
+        Raises:
+            ValueError: If the client is not initialized via the `connect` method.
+
+        Example:
+            # Assuming you have a model instance `request_model` and an API client `api_client`
+            with request_model.connect(auth_config=auth_config) as api:
+                response = api.request()
+
+            # The above example assumes that the `connect` method has been used to initialize the client.
+            # The request method then sends the model's data to the API and returns the API's response.
+        """
+        if hasattr(self, "_api_client"):
+            response = self._api_client.update(
+                self.model_dump(exclude={"_api_client"}, exclude_unset=True)
+            )
+            return response
+        else:
+            raise ValueError("Client not initialized. Use the 'connect' method.")
+
 
 class InvoicesClient(MoloniBaseClient):
 
